# rainforest

[![Test rainforest](https://github.com/MeteoSwiss/rainforest/actions/workflows/test_rainforest.yml/badge.svg)](https://github.com/MeteoSwiss/rainforest/actions/workflows/test_rainforest.yml)

A python library to access and update the gauge/station database of MDR and compute randomForest QPE estimates

Please see https://rainforest.readthedocs.io/en/latest/index.html  for further information

Daniel Wolfensberger, MeteoSwiss-MDRS
March 2020

